@@ -1,10 +1,13 @@
+from dataclasses import dataclass,field
 from .util import get_package_dir as _get_package_dir
 from .paths import Paths
 from .config import Config, init_config as _init_config
 from .content import Content
 
-
+@dataclass(frozen=False,order=True)
 class PYPIPackage:
+
+    config:Config = field(init=True)
     def __init__(self, __config: Config = None):
         self.config = _init_config() if __config is None else __config
 
