@@ -3,26 +3,28 @@ from .templates import pyproject_toml as _pyproject_toml_template
 
 
 class Content:
+
     def __init__(self, __config):
         self.config = __config
 
     @property
-    def _commands(self):
+    def commands(self):
         return _init_commands(self.config)
 
     @property
     def _private_commands(self):
-        return self._commands.private_commands
+        return self.commands.private_commands
 
     @property
     def _public_commands(self):
-        return self._commands.public_commands
+        return self.commands.public_commands
 
     @property
     def pyproject_toml(self) -> str:
         result = _pyproject_toml_template
         for key, value in self.config.items():
-            result = result.replace(f"*{key}*", value)
+            v = str(value).lower() if isinstance(value,bool) else value
+            result = result.replace(f"*{key}*", v)
         return result
 
     @property
